"""Entrypoint module, in case `python -m aop2db` is used."""

from .cli import main

if __name__ == "__main__":
    main()
